==> clist-0.1.tar.gz: clist-0.1/settings.php <==
<?php
/*
 *  Camelot char list php by Yuryu
 *
 *  $Id: settings.php,v 1.15 2003/01/12 12:13:20 yuryu Exp $
 *
 */

// ȥ
define(PAGE_TITLE, "Far East Foundation 饯");

// ɸѥ
define(DEFAULT_PASSWORD, '$1$ADMZ9UP8$8usyc8ggo/MhjyiClSLld1');

// ǡեΥǥ쥯ȥ(Ǹ / Ĥʤ)
define(DATA_DIRECTORY, "./data");

// 饯ǡΥե̾
define(CHARDATA_FNAME, DATA_DIRECTORY . "/chardata.txt");

// ץ쥤ǡΥե̾
define(PLAYERDATA_FNAME, DATA_DIRECTORY . "/playerdata.txt");

// Ѥɤ
// Ѥʤ饮̾Ǥʤ false ˤƤ
define(GUILD_SPEC, false);
// define(GUILD_SPEC, "LoH");

// ɥꥹ
$guild_list = array("DH", "FL", "LoH", "TRS", "UMA");

// ɤбXMLե
$guild_xmls = array("DH" => "http://www.camelotherald.com/guilds/Merlin/1659.xml",
	"FL" => "http://www.camelotherald.com/guilds/Merlin/1251.xml",
	"LoH" => "http://www.camelotherald.com/guilds/Merlin/2332.xml",
	"TRS" => "http://www.camelotherald.com/guilds/Merlin/1168.xml",
	"UMA" => "http://www.camelotherald.com/guilds/Merlin/82.xml");

// 륷ȤΥꥹ
$stylesheets = array (
						array ( 'href' => './clist.css', 'alt' => false, 'title' => '')
					 );

// ɥ󥯡ɽѴơ֥
$guild_ranks = array(
			0 => array('title' => 'Nandemoya san', 'class' => 'gm'),
			1 => array('title' => 'Sanbou', 'class' => 'officer'),
			6 => array('title' => 'Genkina otomodachi'),
			9 => array('title' => 'Shinyu sei')
		);

// Cookie μ̿()
define(COOKIE_EXPIRES_IN, 60 * 60 * 24 * 30);

// դΥեޥå
define(DATE_FORMAT, "y/m/d");

// 饯̾κĹ
define(MAX_CHARNAME_LENGTH, 20);

// ץ쥤̾κĹ
define(MAX_PLAYERNAME_LENGTH, 25);

// ѥɤκǾĹ
define(MIN_PASSWORD_LENGTH, 5);

// ѥɤκĹ
define(MAX_PASSWORD_LENGTH, 20);

// E-mail κĹ
define(MAX_EMAIL_LENGTH, 80);

// Web ɥ쥹κĹ
define(MAX_WEB_LENGTH, 100);

// ȤκĹ
define(MAX_COMMENT_LENGTH, 100);

// ꥹȤɽ
$charlist_columns = array(
	'name' => array( 'title' => 'Name', 'desc' => '饯̾'),
	'level' => array( 'title' => 'Lv', 'desc' => '饯Υ٥', 'callback' => 'cb_show_number_cells', 
		'high' => 40, 'highest' => 50, 'reverse' => true),
//	'rank' => array( 'title' => 'Rank', 'desc' => 'ɥ', 'callback' => 'cb_show_guild_rank', 'hidedefault' => true),
	'class' => array( 'title' => 'Class', 'desc' => '饯ο'),
	'race' => array( 'title' => 'Race', 'desc' => '饯μ²', 'hidedefault' => true),
	'player' => array( 'title' => 'Player', 'desc' => 'ץ쥤䡼̾', 'callback' => 'cb_show_player_cell'),
	'guild' => array( 'title' => 'Guild', 'desc' => '饯β'),
	'rp' => array( 'title' => 'RlmPts', 'desc' => '饯Υȡ Realm Points','callback' => 'cb_show_number_cells',
		'reverse' => true, 'high' => 100000, 'highest' => 400000),
	'lrp' => array( 'title' => 'LWR', 'desc' => '饯轵Realm Points', 'high' => 30000, 'highest' => 70000,
		'hidedefault' => true, 'callback' => 'cb_show_number_cells', 'reverse' => true),
	'death' => array( 'title' => 'Deaths', 'desc' => '饯ΥȡRvR˴', 
		'hidedefault' => true, 'callback' => 'cb_show_number_cells', 'reverse' => true),
	'ldeath' => array( 'title' => 'LWD', 'desc' => '饯轵RvR˴', 'high' => 30, 'highest' => 80,
		'hidedefault' => true, 'callback' => 'cb_show_number_cells', 'reverse' => true),
	'irs' => array('title' => 'IRS', 'desc' => 'I Remain Standing ', 'reverse' => true,
		'callback' => 'cb_show_number_cells', 'decimals' => 1, 'high' => 1000, 'highest' => 2000),
	'Weaponcraft' => array( 'title' => 'Wpn', 'desc' => '٥', 'high' => 700,
		'hidedefault' => true, 'callback' => 'cb_show_number_cells', 'highest' => 1000, 'reverse' => true),
	'Armorcraft' => array( 'title' => 'Arm', 'desc' => '٥', 'high' => 700,
		'hidedefault' => true, 'callback' => 'cb_show_number_cells', 'highest' => 1000, 'reverse' => true),
	'Fletching' => array( 'title' => 'Flt', 'desc' => 'ݳڴ٥', 'high' => 700,
		'hidedefault' => true, 'callback' => 'cb_show_number_cells', 'highest' => 1000, 'reverse' => true),
	'Tailoring' => array( 'title' => 'Tlr', 'desc' => 'ʪ٥', 'high' => 700,
		'hidedefault' => true, 'callback' => 'cb_show_number_cells', 'highest' => 1000, 'reverse' => true),
	'Alchemy' => array( 'title' => 'Alc', 'desc' => 'ϣ٥', 'high' => 700,
		'hidedefault' => true, 'callback' => 'cb_show_number_cells', 'highest' => 1000, 'reverse' => true),
	'Spellcraft' => array( 'title' => 'Spl', 'desc' => 'ˡ٥','high' => 700,
		'hidedefault' => true, 'callback' => 'cb_show_number_cells', 'highest' => 1000, 'reverse' => true),
	'comment' => array( 'title' => 'Comment', 'desc' => 'ץ쥤䡼ҤȤ'),
	'date' => array( 'title' => 'Date', 'desc' => 'ǽ', 'callback' => 'cb_show_link_to_update')
);

require_once("./callback.php");

?>

==> clist-0.1.2.tar.gz: clist-0.1.2/settings.php <==
<?php
/*
 *  Camelot char list php by Yuryu
 *
 *  $Id: settings.php,v 1.18 2003/01/25 06:40:55 yuryu Exp $
 *
 */

// ȥ
define(PAGE_TITLE, "Far East Foundation 饯");

// ɸѥ
define(DEFAULT_PASSWORD, '$1$ADMZ9UP8$8usyc8ggo/MhjyiClSLld1');

// ǡեΥǥ쥯ȥ(Ǹ / Ĥʤ)
define(DATA_DIRECTORY, "./data");

// 饯ǡΥե̾
define(CHARDATA_FNAME, DATA_DIRECTORY . "/chardata.txt");

// ץ쥤ǡΥե̾
define(PLAYERDATA_FNAME, DATA_DIRECTORY . "/playerdata.txt");

// Ѥɤ
// Ѥʤ饮̾Ǥʤ false ˤƤ
define(GUILD_SPEC, false);
// define(GUILD_SPEC, "LoH");

// ɥꥹ
$guild_list = array(
	'ASK' => array('Name' => 'ASUKA', 'Xml' => 'http://www.camelotherald.com/guilds/Merlin/2568.xml'),
	'DH' => array('Name' => 'Double Helix', 'http://www.camelotherald.com/guilds/Merlin/1659.xml'),
	'FL' => array('Name' => 'Free-Lancer', 'Xml' => 'http://www.camelotherald.com/guilds/Merlin/1251.xml'),
	'LoH' => array('Name' => 'Legend of Heroes', 'Xml' => 'http://www.camelotherald.com/guilds/Merlin/2332.xml'),
	'TRS' => array('Name' => 'The Rising Sun', 'Xml' => 'http://www.camelotherald.com/guilds/Merlin/1168.xml'),
	'UMA' => array('Name' => 'UMA', 'Xml' => 'http://www.camelotherald.com/guilds/Merlin/82.xml')
	);
	

// 륷ȤΥꥹ
$stylesheets = array (
						array ( 'href' => './clist.css', 'alt' => false, 'title' => '')
					 );

// ɥ󥯡ɽѴơ֥
$guild_ranks = array(
			0 => array('title' => 'Nandemoya san', 'class' => 'gm'),
			1 => array('title' => 'Sanbou', 'class' => 'officer'),
			6 => array('title' => 'Genkina otomodachi'),
			9 => array('title' => 'Shinyu sei')
		);

// Cookie μ̿()
define(COOKIE_EXPIRES_IN, 60 * 60 * 24 * 30);

// դΥեޥå
define(DATE_FORMAT, "y/m/d");

// 饯̾κĹ
define(MAX_CHARNAME_LENGTH, 20);

// ץ쥤̾κĹ
define(MAX_PLAYERNAME_LENGTH, 25);

// ѥɤκǾĹ
define(MIN_PASSWORD_LENGTH, 5);

// ѥɤκĹ
define(MAX_PASSWORD_LENGTH, 20);

// E-mail κĹ
define(MAX_EMAIL_LENGTH, 80);

// Web ɥ쥹κĹ
define(MAX_WEB_LENGTH, 100);

// ȤκĹ
define(MAX_COMMENT_LENGTH, 100);

// ꥹȤɽ
$charlist_columns = array(
	'name' => array( 'title' => 'Name', 'desc' => '饯̾', 'callback' => 'cb_show_charname'),
	'level' => array( 'title' => 'Lv', 'desc' => '饯Υ٥', 'callback' => 'cb_show_number_cells', 
		'high' => 40, 'highest' => 50, 'reverse' => true),
//	'rank' => array( 'title' => 'Rank', 'desc' => 'ɥ', 'callback' => 'cb_show_guild_rank', 'hidedefault' => true),
	'class' => array( 'title' => 'Class', 'desc' => '饯ο'),
	'race' => array( 'title' => 'Race', 'desc' => '饯μ²', 'hidedefault' => true),
	'player' => array( 'title' => 'Player', 'desc' => 'ץ쥤䡼̾', 'callback' => 'cb_show_player_cell'),
	'guild' => array( 'title' => 'Guild', 'desc' => '饯β',  'callback' => 'cb_show_guild'),
	'rp' => array( 'title' => 'RlmPts', 'desc' => '饯Υȡ Realm Points','callback' => 'cb_show_number_cells',
		'reverse' => true, 'high' => 100000, 'highest' => 400000),
	'lrp' => array( 'title' => 'LWR', 'desc' => '饯轵Realm Points', 'high' => 30000, 'highest' => 70000,
		'hidedefault' => true, 'callback' => 'cb_show_number_cells', 'reverse' => true),
	'death' => array( 'title' => 'Deaths', 'desc' => '饯ΥȡRvR˴', 
		'hidedefault' => true, 'callback' => 'cb_show_number_cells', 'reverse' => true),
	'ldeath' => array( 'title' => 'LWD', 'desc' => '饯轵RvR˴', 'high' => 30, 'highest' => 80,
		'hidedefault' => true, 'callback' => 'cb_show_number_cells', 'reverse' => true),
	'irs' => array('title' => 'IRS', 'desc' => 'I Remain Standing ', 'reverse' => true,
		'callback' => 'cb_show_number_cells', 'decimals' => 1, 'high' => 1000, 'highest' => 2000),
	'Weaponcraft' => array( 'title' => 'Wpn', 'desc' => '٥', 'high' => 700,
		'hidedefault' => true, 'callback' => 'cb_show_number_cells', 'highest' => 1000, 'reverse' => true),
	'Armorcraft' => array( 'title' => 'Arm', 'desc' => '٥', 'high' => 700,
		'hidedefault' => true, 'callback' => 'cb_show_number_cells', 'highest' => 1000, 'reverse' => true),
	'Fletching' => array( 'title' => 'Flt', 'desc' => 'ݳڴ٥', 'high' => 700,
		'hidedefault' => true, 'callback' => 'cb_show_number_cells', 'highest' => 1000, 'reverse' => true),
	'Tailoring' => array( 'title' => 'Tlr', 'desc' => 'ʪ٥', 'high' => 700,
		'hidedefault' => true, 'callback' => 'cb_show_number_cells', 'highest' => 1000, 'reverse' => true),
	'Alchemy' => array( 'title' => 'Alc', 'desc' => 'ϣ٥', 'high' => 700,
		'hidedefault' => true, 'callback' => 'cb_show_number_cells', 'highest' => 1000, 'reverse' => true),
	'Spellcraft' => array( 'title' => 'Spl', 'desc' => 'ˡ٥','high' => 700,
		'hidedefault' => true, 'callback' => 'cb_show_number_cells', 'highest' => 1000, 'reverse' => true),
	'comment' => array( 'title' => 'Comment', 'desc' => 'ץ쥤䡼ҤȤ'),
	'date' => array( 'title' => 'Date', 'desc' => 'ǽ')
);

require_once("./callback.php");

?>
